@@ -7,6 +7,7 @@ from django.template.loader import render_to_string
 from django.utils import timezone
 from knox.models import AuthToken
 from rest_framework import serializers
+from django.conf import settings
 from utils.functions.functions import encrypt, decrypt
 import crypt
 import string
@@ -18,7 +19,7 @@ def send_registration_email(user: User, email: str):
     subject, from_email, to = 'Validación Registro', '%s <%s>' % ('La Página', 'prueba@gmail.com'), email
     activation_key = decrypt(user.extended_user.registration_token)
     context = {
-        "domain": 'http://127.0.0.1:8000',
+        "domain": settings.MAIN_DOMAIN,
         "user": user,
         "activation_key": activation_key
     }
@@ -54,7 +55,7 @@ def ask_restore_password_account_user(
         subject, from_email, to = 'Validación Registro', '%s <%s>' % ('La Página', 'prueba@gmail.com'), user.email
         activation_key = decrypt(extended_user.registration_token)
         context = {
-            "domain": 'http://127.0.0.1:8000',
+            "domain": settings.MAIN_DOMAIN,
             "user": user,
             "activation_key": activation_key
         }
